# Wrgl Python SDK

[![pypi](https://img.shields.io/pypi/v/wrgl)](https://pypi.org/project/wrgl/)
[![docs](https://readthedocs.org/projects/wrgl/badge/)](https://wrgl.readthedocs.io/en/latest/)
[![release-workflow](https://github.com/wrgl/python-sdk/actions/workflows/taggedrelease.yml/badge.svg)](https://github.com/wrgl/python-sdk/actions/workflows/taggedrelease.yml)

This library wraps [Wrgl HTTP API](https://www.wrgl.co/doc/http-api).

## Installation

```
pip install wrgl
```

## Documentation

- [Quickstart](https://wrgl.readthedocs.io/en/latest/quickstart.html)
